==> ark-14.11.95.tar.xz: ark-14.11.95/app/ark_servicemenu.desktop.cmake <==
[Desktop Entry]
Type=Service
ServiceTypes=KonqPopupMenu/Plugin
MimeType=@SUPPORTED_ARK_MIMETYPES@
Actions=arkAutoExtractHere;arkExtractTo;arkExtractHere;
X-KDE-Priority=TopLevel
X-KDE-StartupNotify=false
#StartupNotify=false
X-KDE-Submenu=Extract
X-KDE-Submenu[ar]=استخرِج
X-KDE-Submenu[bg]=Извличане
X-KDE-Submenu[bs]=Raspakivanje
X-KDE-Submenu[ca]=Extreu
X-KDE-Submenu[ca@valencia]=Extrau
X-KDE-Submenu[cs]=Rozbalit
X-KDE-Submenu[da]=Pak ud
X-KDE-Submenu[de]=Entpacken
X-KDE-Submenu[el]=Εξαγωγή
X-KDE-Submenu[en_GB]=Extract
X-KDE-Submenu[es]=Extraer
X-KDE-Submenu[et]=Lahtipakkimine
X-KDE-Submenu[eu]=Atera
X-KDE-Submenu[fi]=Pura
X-KDE-Submenu[fr]=Extraire
X-KDE-Submenu[ga]=Bain amach
X-KDE-Submenu[gl]=Extraer
X-KDE-Submenu[hr]=Otpakiraj
X-KDE-Submenu[hu]=Kibontás
X-KDE-Submenu[ia]=Extrahe
X-KDE-Submenu[it]=Estrai
X-KDE-Submenu[ja]=展開
X-KDE-Submenu[kk]=Тарқату
X-KDE-Submenu[km]=ស្រង់ចេញ​
X-KDE-Submenu[ko]=압축 풀기
X-KDE-Submenu[lt]=Išpakuoti
X-KDE-Submenu[mr]=पुर्ववत करा
X-KDE-Submenu[nb]=Pakk ut
X-KDE-Submenu[nds]=Utpacken
X-KDE-Submenu[nl]=Uitpakken
X-KDE-Submenu[pa]=ਇੱਥੇ ਖਿਲਾਰੋ
X-KDE-Submenu[pl]=Rozpakuj
X-KDE-Submenu[pt]=Extrair
X-KDE-Submenu[pt_BR]=Extrair
X-KDE-Submenu[ro]=Extrage
X-KDE-Submenu[ru]=Распаковать
X-KDE-Submenu[sk]=Rozbaliť
X-KDE-Submenu[sl]=Razširi
X-KDE-Submenu[sr]=Распакуј
X-KDE-Submenu[sr@ijekavian]=Распакуј
X-KDE-Submenu[sr@ijekavianlatin]=Raspakuj
X-KDE-Submenu[sr@latin]=Raspakuj
X-KDE-Submenu[sv]=Packa upp
X-KDE-Submenu[tr]=Çıkart
X-KDE-Submenu[ug]=ئايرىش
X-KDE-Submenu[uk]=Видобути
X-KDE-Submenu[x-test]=xxExtractxx
X-KDE-Submenu[zh_CN]=解压缩
X-KDE-Submenu[zh_TW]=解開

[Desktop Action arkExtractHere]
Name=Extract Archive Here
Name[ar]=فك الأرشيف هنا
Name[ast]=Estrayer archivu comprimíu equí
Name[bg]=Извличане тук
Name[bs]=Raspakuj arhivu ovde
Name[ca]=Extreu l'arxiu aquí
Name[ca@valencia]=Extrau l'arxiu ací
Name[cs]=Rozbalit archiv sem
Name[da]=Udpak arkiv her
Name[de]=Archiv hierher auspacken
Name[el]=Εξαγωγή αρχειοθήκης εδώ
Name[en_GB]=Extract Archive Here
Name[es]=Extraer archivo comprimido aquí
Name[et]=Paki arhiiv siia lahti
Name[eu]=Atera artxiboa hemen
Name[fi]=Pura paketti tähän
Name[fr]=Extraire l'archive ici
Name[ga]=Bain an chartlann amach agus cuir é anseo
Name[gl]=Extraer o arquivo aquí
Name[hr]=Ovdje otpakiraj arhivu
Name[hu]=Kibontás ide
Name[ia]=Extrahe archivo hic
Name[id]=Ekstrak Arsip di Sini
Name[it]=Estrai l'archivio qui
Name[ja]=アーカイブをここに展開
Name[kk]=Архивті мынаған тарқату
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​នៅ​ទីនេះ
Name[ko]=여기에 압축 풀기
Name[lt]=Čia išpakuoti archyvą
Name[lv]=Atspiest arhīvu šeit
Name[mr]=येथे संग्रह पुर्ववत करा
Name[nb]=Pakk ut arkivet her
Name[nds]=Archiev hier utpacken
Name[nl]=Archief hier uitpakken
Name[nn]=Pakk ut arkivet her
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ
Name[pl]=Rozpakuj archiwum tutaj
Name[pt]=Extrair o Pacote para Aqui
Name[pt_BR]=Extrair arquivo aqui
Name[ro]=Extrage arhiva aici
Name[ru]=В эту папку
Name[sk]=Rozbaliť archív sem
Name[sl]=Razširi arhiv sem
Name[sq]=Ekstrakto Arkivin Këtu
Name[sr]=Распакуј архиву овде
Name[sr@ijekavian]=Распакуј архиву овдје
Name[sr@ijekavianlatin]=Raspakuj arhivu ovdje
Name[sr@latin]=Raspakuj arhivu ovde
Name[sv]=Packa upp arkiv här
Name[th]=คลายแฟ้มจัดเก็บไว้ที่นี่
Name[tr]=Arşivi Buraya Çıkart
Name[uk]=Видобути архів сюди
Name[wa]=Saetchî l' årtchive foû cial
Name[x-test]=xxExtract Archive Herexx
Name[zh_CN]=在此解压缩归档
Name[zh_TW]=在此解壓縮
Icon=ark
Exec=ark --batch --autodestination %F

[Desktop Action arkExtractTo]
Name=Extract Archive To...
Name[ar]=فك الأرشيف إلى...
Name[ast]=Estrayer archivu comprimíu en...
Name[bg]=Извличане в...
Name[bs]=Raspakuj arhivu u...
Name[ca]=Extreu l'arxiu a...
Name[ca@valencia]=Extrau l'arxiu a...
Name[cs]=Rozbalit archiv do...
Name[da]=Udpak arkiv til...
Name[de]=Archiv auspacken nach ...
Name[el]=Εξαγωγή αρχειοθήκης σε...
Name[en_GB]=Extract Archive To...
Name[es]=Extraer archivo comprimido en...
Name[et]=Paki arhiiv lahti...
Name[eu]=Atera artxiboa hona...
Name[fi]=Pura paketti…
Name[fr]=Extraire l'archive vers...
Name[ga]=Bain an chartlann amach go...
Name[gl]=Extraer o arquivo en...
Name[hr]=Otpakiraj arhivu u …
Name[hu]=Kibontás ide…
Name[ia]=Extrahe archivo in...
Name[id]=Ekstrak Arsip ke...
Name[it]=Estrai l'archivio in...
Name[ja]=アーカイブを展開...
Name[kk]=Мынаған тарқату...
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​ទៅ...
Name[ko]=다음 경로에 압축 풀기...
Name[lt]=Išpakuoti archyvą į...
Name[lv]=Atspiest arhīvu uz...
Name[mr]=यावर संग्रह पुर्ववत करा...
Name[nb]=Pakk ut arkivet til …
Name[nds]=Archiev utpacken as...
Name[nl]=Archief uitpakken naar...
Name[nn]=Pakk ut arkivet til …
Name[pa]=...ਵਜੋਂ ਅਕਾਇਵ ਐਕਸਟਰੈਕਟ
Name[pl]=Rozpakuj archiwum do...
Name[pt]=Extrair o Pacote Para...
Name[pt_BR]=Extrair arquivo para...
Name[ro]=Extrage arhiva în...
Name[ru]=Указать путь...
Name[sk]=Rozbaliť archív do...
Name[sl]=Razširi arhiv v ...
Name[sq]=Ekstrakto Arkivin Tek...
Name[sr]=Распакуј архиву у...
Name[sr@ijekavian]=Распакуј архиву у...
Name[sr@ijekavianlatin]=Raspakuj arhivu u...
Name[sr@latin]=Raspakuj arhivu u...
Name[sv]=Packa upp arkiv i...
Name[th]=คลายแฟ้มจัดเก็บไปยัง...
Name[tr]=Arşivi Şuraya Çıkart...
Name[uk]=Видобути архів до...
Name[wa]=Saetchî l' årtchive foû eyet l' rilomer...
Name[x-test]=xxExtract Archive To...xx
Name[zh_CN]=解压缩归档到...
Name[zh_TW]=解壓縮到...
Icon=ark
Exec=ark --batch --autodestination --dialog %F

[Desktop Action arkAutoExtractHere]
Name=Extract Archive Here, Autodetect Subfolder
Name[ar]=فك الأرشيف هنا ، تعرف تلقائي للمجلدات الفرعية
Name[ast]=Estrayer archivu comprimíu equí, autodeteutar subcarpeta
Name[bg]=Извличане тук, автоматична подпапка
Name[bs]=Raspakuj arhivu ovdje, pogodi poddirektorij
Name[ca]=Extreu l'arxiu aquí, detecta automàticament la subcarpeta
Name[ca@valencia]=Extrau l'arxiu ací, detecta automàticament la subcarpeta
Name[cs]=Rozbalit archiv sem, automaticky detekovat podsložku
Name[da]=Udpak arkiv her og find automatisk undermappe
Name[de]=Archiv hierher auspacken, Unterordner selbständig ermitteln
Name[el]=Εξαγωγή αρχειοθήκης εδώ, αυτόματη επιλογή υποφακέλου
Name[en_GB]=Extract Archive Here, Autodetect Subfolder
Name[es]=Extraer archivo comprimido aquí, autodetectar subcarpeta
Name[et]=Paki arhiiv siia lahti, tuvasta automaatselt alamkataloog
Name[eu]=Atera artxiboa hona, automatikoki detektatu azpikarpeta
Name[fi]=Pura paketti tähän, tunnista alikansio automaattisesti
Name[fr]=Extraire l'archive ici, auto-détecter les sous-dossiers
Name[ga]=Bain an chartlann amach agus cuir é anseo, braith fofhillteán go huathoibríoch
Name[gl]=Extraer o arquivo aquí, detectar o subcartafol
Name[hr]=Ovdje otpakiraj arhivu i automatski prepoznaj podmapu
Name[hu]=Kibontás ide (automatikus almappalétrehozás)
Name[ia]=Extrahe archivo hic, auto-releva subdossier
Name[id]=Ekstrak Arsip di Sini, Deteksi Otomatis Subfolder
Name[it]=Estrai l'archivio qui, autorileva la sottocartella
Name[ja]=アーカイブをここに展開、サブフォルダを自動検出
Name[kk]=Мынаған, ішкі қапшығына тарқату
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​នៅ​ទីនេះ រកថត​រង​ឃើញ​ដោយ​ស្វ័យ​ប្រវត្តិ
Name[ko]=하위 폴더를 감지해서 여기에 압축 풀기
Name[lt]=Išpakuoti archyvą čia, automatiškai rasti poaplankius
Name[lv]=Atspiest arhīvu šeit, automātiska apakšmape
Name[mr]=येथे संग्रह पुर्ववत करा, उपसंचयीका स्वंयंशोध
Name[nb]=Pakk ut arkivet her, finn undermapper automatisk
Name[nds]=Archiev hier utpacken, Ünnerorner autom. opdecken
Name[nl]=Archief hier uitpakken, submap autodetecteren
Name[nn]=Pakk ut arkivet her / til undermappe
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ, ਸਬ-ਫੋਲਡਰ ਆਪੇ ਖੋਜੋ
Name[pl]=Rozpakuj archiwum tutaj, wykryj podkatalogi
Name[pt]=Extrair o Pacote Aqui com Detecção da Sub-Pasta
Name[pt_BR]=Extrair aqui detectando subpasta
Name[ro]=Extrage arhiva aici, autodetectează subdosarul
Name[ru]=Во вложенную папку
Name[sk]=Rozbaliť archív sem, automaticky určiť podpriečinok
Name[sl]=Razširi arhiv sem, samodejno zaznaj podmapo
Name[sq]=Ekstrakto Arkivin Këtu, Vetëdallo Nëndosjen
Name[sr]=Распакуј архиву овде, погоди потфасциклу
Name[sr@ijekavian]=Распакуј архиву овдје, погоди потфасциклу
Name[sr@ijekavianlatin]=Raspakuj arhivu ovdje, pogodi potfasciklu
Name[sr@latin]=Raspakuj arhivu ovde, pogodi potfasciklu
Name[sv]=Packa upp arkiv här, detektera underkatalog automatiskt
Name[th]=คลายแฟ้มจัดเก็บไว้ที่นี่, และตรวจสอบโฟลเดอร์ย่อยอัตโนมัติ
Name[tr]=Arşivi Buraya Çıkart, Alt Dizinleri Otomatik Belirle
Name[uk]=Видобути архів сюди, автоматично визначити підтеку
Name[wa]=Saetchî l' årtchive foû cial, deteccion otomatike do ridant efant
Name[x-test]=xxExtract Archive Here, Autodetect Subfolderxx
Name[zh_CN]=在此解压缩归档，自动探测子文件夹
Name[zh_TW]=在此解壓縮，自動偵測子資料夾
Icon=ark
Exec=ark --batch --autodestination --autosubfolder %F

==> ark-15.08.0.tar.xz: ark-15.08.0/app/ark_servicemenu.desktop.cmake <==
[Desktop Entry]
Type=Service
ServiceTypes=KonqPopupMenu/Plugin
MimeType=@SUPPORTED_ARK_MIMETYPES@
Actions=arkAutoExtractHere;arkExtractTo;arkExtractHere;
X-KDE-Priority=TopLevel
X-KDE-StartupNotify=false
#StartupNotify=false
X-KDE-Submenu=Extract
X-KDE-Submenu[ar]=استخرِج
X-KDE-Submenu[ast]=Estrayer
X-KDE-Submenu[bg]=Извличане
X-KDE-Submenu[bs]=Raspakivanje
X-KDE-Submenu[ca]=Extreu
X-KDE-Submenu[ca@valencia]=Extrau
X-KDE-Submenu[cs]=Rozbalit
X-KDE-Submenu[da]=Pak ud
X-KDE-Submenu[de]=Entpacken
X-KDE-Submenu[el]=Εξαγωγή
X-KDE-Submenu[en_GB]=Extract
X-KDE-Submenu[es]=Extraer
X-KDE-Submenu[et]=Lahtipakkimine
X-KDE-Submenu[eu]=Atera
X-KDE-Submenu[fi]=Pura
X-KDE-Submenu[fr]=Extraire
X-KDE-Submenu[ga]=Bain amach
X-KDE-Submenu[gl]=Extraer
X-KDE-Submenu[hr]=Otpakiraj
X-KDE-Submenu[hu]=Kibontás
X-KDE-Submenu[ia]=Extrahe
X-KDE-Submenu[it]=Estrai
X-KDE-Submenu[ja]=展開
X-KDE-Submenu[kk]=Тарқату
X-KDE-Submenu[km]=ស្រង់ចេញ​
X-KDE-Submenu[ko]=압축 풀기
X-KDE-Submenu[lt]=Išpakuoti
X-KDE-Submenu[mr]=पुर्ववत करा
X-KDE-Submenu[nb]=Pakk ut
X-KDE-Submenu[nds]=Utpacken
X-KDE-Submenu[nl]=Uitpakken
X-KDE-Submenu[pa]=ਇੱਥੇ ਖਿਲਾਰੋ
X-KDE-Submenu[pl]=Wypakuj
X-KDE-Submenu[pt]=Extrair
X-KDE-Submenu[pt_BR]=Extrair
X-KDE-Submenu[ro]=Extrage
X-KDE-Submenu[ru]=Распаковать
X-KDE-Submenu[sk]=Rozbaliť
X-KDE-Submenu[sl]=Razširi
X-KDE-Submenu[sr]=Распакуј
X-KDE-Submenu[sr@ijekavian]=Распакуј
X-KDE-Submenu[sr@ijekavianlatin]=Raspakuj
X-KDE-Submenu[sr@latin]=Raspakuj
X-KDE-Submenu[sv]=Packa upp
X-KDE-Submenu[tr]=Çıkart
X-KDE-Submenu[ug]=ئايرىش
X-KDE-Submenu[uk]=Видобути
X-KDE-Submenu[x-test]=xxExtractxx
X-KDE-Submenu[zh_CN]=解压缩
X-KDE-Submenu[zh_TW]=解開

[Desktop Action arkExtractHere]
Name=Extract Archive Here
Name[ar]=فك الأرشيف هنا
Name[ast]=Estrayer equí l'archivu
Name[bg]=Извличане тук
Name[bs]=Raspakuj arhivu ovde
Name[ca]=Extreu l'arxiu aquí
Name[ca@valencia]=Extrau l'arxiu ací
Name[cs]=Rozbalit archiv sem
Name[da]=Udpak arkiv her
Name[de]=Archiv hierher auspacken
Name[el]=Εξαγωγή αρχειοθήκης εδώ
Name[en_GB]=Extract Archive Here
Name[es]=Extraer archivo comprimido aquí
Name[et]=Paki arhiiv siia lahti
Name[eu]=Atera artxiboa hemen
Name[fi]=Pura paketti tähän
Name[fr]=Extraire l'archive ici
Name[ga]=Bain an chartlann amach agus cuir é anseo
Name[gl]=Extraer o arquivo aquí
Name[hr]=Ovdje otpakiraj arhivu
Name[hu]=Kibontás ide
Name[ia]=Extrahe archivo hic
Name[id]=Ekstrak Arsip di Sini
Name[it]=Estrai l'archivio qui
Name[ja]=アーカイブをここに展開
Name[kk]=Архивті мынаған тарқату
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​នៅ​ទីនេះ
Name[ko]=여기에 압축 풀기
Name[lt]=Čia išpakuoti archyvą
Name[lv]=Atspiest arhīvu šeit
Name[mr]=येथे संग्रह पुर्ववत करा
Name[nb]=Pakk ut arkivet her
Name[nds]=Archiev hier utpacken
Name[nl]=Archief hier uitpakken
Name[nn]=Pakk ut arkivet her
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ
Name[pl]=Wypakuj archiwum tutaj
Name[pt]=Extrair o Pacote para Aqui
Name[pt_BR]=Extrair arquivo aqui
Name[ro]=Extrage arhiva aici
Name[ru]=В эту папку
Name[sk]=Rozbaliť archív sem
Name[sl]=Razširi arhiv sem
Name[sq]=Ekstrakto Arkivin Këtu
Name[sr]=Распакуј архиву овде
Name[sr@ijekavian]=Распакуј архиву овдје
Name[sr@ijekavianlatin]=Raspakuj arhivu ovdje
Name[sr@latin]=Raspakuj arhivu ovde
Name[sv]=Packa upp arkiv här
Name[th]=คลายแฟ้มจัดเก็บไว้ที่นี่
Name[tr]=Arşivi Buraya Çıkart
Name[uk]=Видобути архів сюди
Name[wa]=Saetchî l' årtchive foû cial
Name[x-test]=xxExtract Archive Herexx
Name[zh_CN]=在此解压缩归档
Name[zh_TW]=在此解壓縮
Icon=ark
Exec=ark --batch --autodestination %F

[Desktop Action arkExtractTo]
Name=Extract Archive To...
Name[ar]=فك الأرشيف إلى...
Name[ast]=Estrayer l'archivu en...
Name[bg]=Извличане в...
Name[bs]=Raspakuj arhivu u...
Name[ca]=Extreu l'arxiu a...
Name[ca@valencia]=Extrau l'arxiu a...
Name[cs]=Rozbalit archiv do...
Name[da]=Udpak arkiv til...
Name[de]=Archiv auspacken nach ...
Name[el]=Εξαγωγή αρχειοθήκης σε...
Name[en_GB]=Extract Archive To...
Name[es]=Extraer archivo comprimido en...
Name[et]=Paki arhiiv lahti...
Name[eu]=Atera artxiboa hona...
Name[fi]=Pura paketti…
Name[fr]=Extraire l'archive vers...
Name[ga]=Bain an chartlann amach go...
Name[gl]=Extraer o arquivo en...
Name[hr]=Otpakiraj arhivu u …
Name[hu]=Kibontás ide…
Name[ia]=Extrahe archivo in...
Name[id]=Ekstrak Arsip ke...
Name[it]=Estrai l'archivio in...
Name[ja]=アーカイブを展開...
Name[kk]=Мынаған тарқату...
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​ទៅ...
Name[ko]=다음 경로에 압축 풀기...
Name[lt]=Išpakuoti archyvą į...
Name[lv]=Atspiest arhīvu uz...
Name[mr]=यावर संग्रह पुर्ववत करा...
Name[nb]=Pakk ut arkivet til …
Name[nds]=Archiev utpacken as...
Name[nl]=Archief uitpakken naar...
Name[nn]=Pakk ut arkivet til …
Name[pa]=...ਵਜੋਂ ਅਕਾਇਵ ਐਕਸਟਰੈਕਟ
Name[pl]=Wypakuj archiwum do...
Name[pt]=Extrair o Pacote Para...
Name[pt_BR]=Extrair arquivo para...
Name[ro]=Extrage arhiva în...
Name[ru]=Указать путь...
Name[sk]=Rozbaliť archív do...
Name[sl]=Razširi arhiv v ...
Name[sq]=Ekstrakto Arkivin Tek...
Name[sr]=Распакуј архиву у...
Name[sr@ijekavian]=Распакуј архиву у...
Name[sr@ijekavianlatin]=Raspakuj arhivu u...
Name[sr@latin]=Raspakuj arhivu u...
Name[sv]=Packa upp arkiv i...
Name[th]=คลายแฟ้มจัดเก็บไปยัง...
Name[tr]=Arşivi Şuraya Çıkart...
Name[uk]=Видобути архів до...
Name[wa]=Saetchî l' årtchive foû eyet l' rilomer...
Name[x-test]=xxExtract Archive To...xx
Name[zh_CN]=解压缩归档到...
Name[zh_TW]=解壓縮到...
Icon=ark
Exec=ark --batch --autodestination --dialog %F

[Desktop Action arkAutoExtractHere]
Name=Extract Archive Here, Autodetect Subfolder
Name[ar]=فك الأرشيف هنا ، تعرف تلقائي للمجلدات الفرعية
Name[ast]=Estrayer equí l'archivu, autodeteutar socarpeta
Name[bg]=Извличане тук, автоматична подпапка
Name[bs]=Raspakuj arhivu ovdje, pogodi poddirektorij
Name[ca]=Extreu l'arxiu aquí, detecta automàticament la subcarpeta
Name[ca@valencia]=Extrau l'arxiu ací, detecta automàticament la subcarpeta
Name[cs]=Rozbalit archiv sem, automaticky detekovat podsložku
Name[da]=Udpak arkiv her og find automatisk undermappe
Name[de]=Archiv hierher auspacken, Unterordner selbständig ermitteln
Name[el]=Εξαγωγή αρχειοθήκης εδώ, αυτόματη επιλογή υποφακέλου
Name[en_GB]=Extract Archive Here, Autodetect Subfolder
Name[es]=Extraer archivo comprimido aquí, autodetectar subcarpeta
Name[et]=Paki arhiiv siia lahti, tuvasta automaatselt alamkataloog
Name[eu]=Atera artxiboa hona, automatikoki detektatu azpikarpeta
Name[fi]=Pura paketti tähän, tunnista alikansio automaattisesti
Name[fr]=Extraire l'archive ici, auto-détecter les sous-dossiers
Name[ga]=Bain an chartlann amach agus cuir é anseo, braith fofhillteán go huathoibríoch
Name[gl]=Extraer o arquivo aquí, detectar o subcartafol
Name[hr]=Ovdje otpakiraj arhivu i automatski prepoznaj podmapu
Name[hu]=Kibontás ide (automatikus almappalétrehozás)
Name[ia]=Extrahe archivo hic, auto-releva subdossier
Name[id]=Ekstrak Arsip di Sini, Deteksi Otomatis Subfolder
Name[it]=Estrai l'archivio qui, autorileva la sottocartella
Name[ja]=アーカイブをここに展開、サブフォルダを自動検出
Name[kk]=Мынаған, ішкі қапшығына тарқату
Name[km]=ស្រង់ចេញ​ប័ណ្ណសារ​នៅ​ទីនេះ រកថត​រង​ឃើញ​ដោយ​ស្វ័យ​ប្រវត្តិ
Name[ko]=하위 폴더를 감지해서 여기에 압축 풀기
Name[lt]=Išpakuoti archyvą čia, automatiškai rasti poaplankius
Name[lv]=Atspiest arhīvu šeit, automātiska apakšmape
Name[mr]=येथे संग्रह पुर्ववत करा, उपसंचयीका स्वंयंशोध
Name[nb]=Pakk ut arkivet her, finn undermapper automatisk
Name[nds]=Archiev hier utpacken, Ünnerorner autom. opdecken
Name[nl]=Archief hier uitpakken, submap autodetecteren
Name[nn]=Pakk ut arkivet her / til undermappe
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ, ਸਬ-ਫੋਲਡਰ ਆਪੇ ਖੋਜੋ
Name[pl]=Wypakuj archiwum tutaj, wykryj podkatalogi
Name[pt]=Extrair o Pacote Aqui com Detecção da Sub-Pasta
Name[pt_BR]=Extrair aqui detectando subpasta
Name[ro]=Extrage arhiva aici, autodetectează subdosarul
Name[ru]=Во вложенную папку
Name[sk]=Rozbaliť archív sem, automaticky určiť podpriečinok
Name[sl]=Razširi arhiv sem, samodejno zaznaj podmapo
Name[sq]=Ekstrakto Arkivin Këtu, Vetëdallo Nëndosjen
Name[sr]=Распакуј архиву овде, погоди потфасциклу
Name[sr@ijekavian]=Распакуј архиву овдје, погоди потфасциклу
Name[sr@ijekavianlatin]=Raspakuj arhivu ovdje, pogodi potfasciklu
Name[sr@latin]=Raspakuj arhivu ovde, pogodi potfasciklu
Name[sv]=Packa upp arkiv här, detektera underkatalog automatiskt
Name[th]=คลายแฟ้มจัดเก็บไว้ที่นี่, และตรวจสอบโฟลเดอร์ย่อยอัตโนมัติ
Name[tr]=Arşivi Buraya Çıkart, Alt Dizinleri Otomatik Belirle
Name[uk]=Видобути архів сюди, автоматично визначити підтеку
Name[wa]=Saetchî l' årtchive foû cial, deteccion otomatike do ridant efant
Name[x-test]=xxExtract Archive Here, Autodetect Subfolderxx
Name[zh_CN]=在此解压缩归档，自动探测子文件夹
Name[zh_TW]=在此解壓縮，自動偵測子資料夾
Icon=ark
Exec=ark --batch --autodestination --autosubfolder %F
